pub struct EPIC_BASIC_REALM { /* private fields */ }

Methods from Deref<Target = HeaderValue>

Yields a &str slice if the HeaderValue only contains visible ASCII chars.

This function will perform a scan of the header value, checking all the characters.

Examples
let val = HeaderValue::from_static("hello");
assert_eq!(val.to_str().unwrap(), "hello");

Returns the length of self.

This length is in bytes.

Examples
let val = HeaderValue::from_static("hello");
assert_eq!(val.len(), 5);

Returns true if the HeaderValue has a length of zero bytes.

Examples
let val = HeaderValue::from_static("");
assert!(val.is_empty());

let val = HeaderValue::from_static("hello");
assert!(!val.is_empty());

Converts a HeaderValue to a byte slice.

Examples
let val = HeaderValue::from_static("hello");
assert_eq!(val.as_bytes(), b"hello");

Returns true if the value represents sensitive data.

Sensitive data could represent passwords or other data that should not be stored on disk or in memory. This setting can be used by components like caches to avoid storing the value. HPACK encoders must set the header field to never index when is_sensitive returns true.

Note that sensitivity is not factored into equality or ordering.

Examples
let mut val = HeaderValue::from_static("my secret");

val.set_sensitive(true);
assert!(val.is_sensitive());

val.set_sensitive(false);
assert!(!val.is_sensitive());