Struct stack_test_epic_api::BlockHeaderInfo
source · [−]Fields
hash: Stringheight: u64Height of this block since the genesis block (height 0)
previous: StringHash of the block previous to this in the chain.
Implementations
sourceimpl BlockHeaderInfo
impl BlockHeaderInfo
pub fn from_header(header: &BlockHeader) -> BlockHeaderInfo